#!/bin/bash
# © Copyright [2016 - 2020] Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates and licensors
# (“Micro Focus”) are as may be set forth in the express warranty statements accompanying such
# products and services. Nothing herein should be construed as constituting an additional
# warranty. Micro Focus shall not be liable for technical or editorial errors or omissions
# contained herein. The information contained herein is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains confidential information
# and a valid license is required for possession, use or copying. If this work is provided to the
# U.S. Government, consistent with FAR 12.211 and 12.212, Commercial Computer Software,
# Computer Software Documentation, and Technical Data for Commercial Items are licensed
# to the U.S. Government under vendor's standard commercial license.


if [ $# -ne 1 ]; then
	echo "Invalid usage.\n"
	echo "$0 <service name>\n"
	exit 1
fi

DOCKER_PATH="/usr/bin/docker"
if [ -f $DOCKER_PATH ]; then
	pgrep dockerd > /dev/null 2>&1
	if [ $? -ne 0 ]; then
		exit 1
	fi

	docker rm $(docker ps -a -f "status=exited" -f "status=dead" -q) --force >> /dev/null 2>&1

	ACTUAL=`rpm -q --queryformat "%{VERSION}-%{RELEASE}" sles-oes-cis-$1-docker-image`
	docker inspect microfocus/cis-$1:$ACTUAL > /dev/null 2>&1
	if [ $? -eq 0 ]; then
	    docker tag microfocus/cis-$1:$ACTUAL microfocus/cis-$1 > /dev/null 2>&1
	    if [ $? -ne 0 ]; then
		    echo "Tagging microfocus/cis-$1:$ACTUAL to latest failed."
		    exit 1
	    fi
		exit 0
	fi
       
    docker rmi $(docker images --filter "reference=microfocus/cis-$1" -q) --force > /dev/null 2>&1
        
	docker load -i /usr/share/suse-docker-images/sles-oes-cis-$1-* > /dev/null 2>&1
	if [ $? -ne 0 ]; then
		echo "Importing latest docker image failed."
		exit 1
	fi

        CUR_VERSION=`docker images microfocus/cis-$1 | grep "microfocus/cis-$1" | awk -F ' ' '{print $2}'`
        docker tag microfocus/cis-$1:$CUR_VERSION microfocus/cis-$1:$ACTUAL

	docker tag microfocus/cis-$1:$ACTUAL  microfocus/cis-$1 > /dev/null 2>&1
	if [ $? -ne 0 ]; then
	    echo "Tagging microfocus/cis-$1:$ACTUAL to latest failed."
	    exit 1
	fi
fi
